<?php
namespace Teknisa\PLA\Modules\Cardapio\Services;
/**
 * 01/06/2015
 * @author Francis
 */

use Setforms2\Shared\ORM\DateTime;
use Zeedhi\Framework\DTO;

class ConfigurarCardapio {

    const ATIVO = 'S';

    protected $entityManager;
    /** @var Environment */
    protected $environment;
    protected $crudService;

    public function __construct($entityManager, $environment, $crudService) {
        $this->entityManager = $entityManager;
        $this->environment   = $environment;
        $this->crudService   = $crudService;
    }

    private function retornaConfiguracao($cdservfili, $seq, $dtrefecnfmes) {

        return $this->entityManager->getRepository('\Teknisa\Model\Planejamento\Entities\Cnfcames')
            ->findOneBy(
                array(
                    "nrorg" => $this->environment->getNrOrg(),
                    "cdfilial" => $this->environment->getCdFilial(),
                    "nrseqcnfmes" => $seq,
                    "dtrefecnfmes" => new \DateTime($dtrefecnfmes),
                    "cdservfili" => $cdservfili
                )
            );

    }

    private function retornaComposicao($nrcardapio, $seq) {

       return $this->entityManager->getRepository('\Teknisa\Model\Planejamento\Entities\Compcard')
            ->findOneBy(
                array(
                    "nrorg" => $this->environment->getNrOrg(),
                    "cdfilial" => $this->environment->getCdFilial(),
                    "nrcardapio" => $nrcardapio,
                    "nrseqpratcar" => $seq
                )
            );

    }

    private function retornaCardapio($cdfilial, $cdservfili, $dtrefecnfmes, $seq) {

       return $this->entityManager->getRepository('\Teknisa\Model\Planejamento\Entities\Cardadia')
            ->findBy(
                array(
                    "nrorg" => $this->environment->getNrOrg(),
                    "cdfilial" => $cdfilial,
                    "cdservfili" => $cdservfili,
                    "dtmescard" => new \DateTime($dtrefecnfmes)
                )
            );

    }

    public function inserirConfiguracao($cdfilial, $cdservfili, $dtrefecnfmes, $cdtipoprat, $nrseqcnfmes, $idopccnfmes, $idimpcnfmes, $idconcnfmes, $dscompltpmes, $cdcontainer, $nrgrupoemb, $idreservamymenu) {
        $row = array();
        
        $row['CDFILIAL']        = $cdfilial;
        $row['CDSERVFILI']      = $cdservfili;
        $row['NRSEQCNFMES']     = $nrseqcnfmes;
        $row['NRORDCNFMES']     = $nrseqcnfmes;
        $row['CDTIPOPRAT']      = $cdtipoprat;
        $row['DTREFECNFMES']    = $dtrefecnfmes;
        $row['IDOPCCNFMES']     = $idopccnfmes;
        $row['IDTPPRATSEGM']    = "S";
        $row['IDTPPRATTERM']    = "S";
        $row['IDTPPRATQUAM']    = "S";
        $row['IDTPPRATQUIM']    = "S";
        $row['IDTPPRATSEXM']    = "S";
        $row['IDTPPRATSABM']    = "S";
        $row['IDTPPRATDOMM']    = "S";
        $row['IDTPPRATFERM']    = "S";
        $row['IDCONCNFMES']     = "N";
        $row['IDIMPCNFMES']     = $idimpcnfmes;
        $row['IDCONCNFMES']     = $idconcnfmes;
        $row['DSCOMPLTPMES']    = $dscompltpmes;
        $row['CDCONTAINER']     = $cdcontainer;
        $row['NRGRUPOEMB']      = $nrgrupoemb;
        $row['IDRESERVAMYMENU'] = $idreservamymenu;
        
        
        $row['__is_new'] = true;
        $newRequestOrigem = new DTO\Request\Row($row,"","","");
        $cnfcard = $this->crudService->getRowsToSave($newRequestOrigem, 'cnfcames');
        $this->crudService->save('cnfcames',$cnfcard); 

    }

    public function alterarConfiguracao($cdfilial, $cdservfili, $dtrefecnfmes, $nrseqcnfmes, $idopccnfmes, $idimpcnfmes, $idconcnfmes, $dscompltpmes, $cdcontainer, $nrgrupoemb, $idreservamymenu) {
        
        $row["CDFILIAL"]        = $cdfilial;
        $row["CDSERVFILI"]      = $cdservfili;
        $row["NRSEQCNFMES"]     = $nrseqcnfmes;
        $row["DTREFECNFMES"]    = $dtrefecnfmes;
        $row['IDOPCCNFMES']     = $idopccnfmes;
        $row['IDIMPCNFMES']     = $idimpcnfmes;
        $row['IDCONCNFMES']     = $idconcnfmes;
        $row['NRSEQCNFMES']     = $nrseqcnfmes;
        $row['DSCOMPLTPMES']    = $dscompltpmes;
        $row['CDCONTAINER']     = $cdcontainer;
        $row['NRGRUPOEMB']      = $nrgrupoemb;
        $row['IDRESERVAMYMENU'] = $idreservamymenu;

        $row['__is_new'] = false;
        $newRequestOrigem = new DTO\Request\Row($row,"","","");
        $cnfcard = $this->crudService->getRowsToSave($newRequestOrigem, 'cnfcames');
        $this->crudService->save('cnfcames',$cnfcard); 

    }

    public function apagarCardapio($cdfilial, $cdservfili, $dtrefecnfmes, $seq) {

        $cardapios = $this->retornaCardapio($cdfilial, $cdservfili, $dtrefecnfmes, $seq);
        if($cardapios) {

            foreach ($cardapios as $cardapio) {

                $composicao = $this->retornaComposicao($cardapio->getNrcardapio(), $seq);
                
                if($composicao) {
                    $this->entityManager->remove($composicao);
                    $this->entityManager->flush();

                }

            }

        }

        $configuracao = $this->retornaConfiguracao($cdservfili, $seq, $dtrefecnfmes);

        if($configuracao) {
            $this->entityManager->remove($configuracao);
            $this->entityManager->flush();
        }

    }

    private function atualizarPratos($cdservfili, $dtrefecnfmes, $seq, $para) {
        $cdfilial = $this->environment->getCdFilial();
        $cardapios = $this->retornaCardapio($cdfilial, $cdservfili, $dtrefecnfmes, $seq);

        foreach ($cardapios as $cardapio) {

            $composicao = $this->retornaComposicao($cardapio->getNrcardapio(), $seq);
            
            if($composicao) {

                $composicao->setNrordpratcar($para);
                $this->entityManager->persist($composicao);
                $this->entityManager->flush();

            }

        }


    }

    public function atualizarCardapio($cdfilial, $cdservfili, $dtrefecnfmes, $de, $para) {
try{
        $configuracao = $this->entityManager->getRepository('\Teknisa\Model\Planejamento\Entities\Cnfcames')
            ->findOneBy(
                array(
                    "nrorg" => $this->environment->getNrOrg(),
                    "cdfilial" => $cdfilial,
                    "nrseqcnfmes" => $de,
                    "dtrefecnfmes" => new \DateTime($dtrefecnfmes),
                    "cdservfili" => $cdservfili
                )
            );

        if ($configuracao) {
            $configuracao->setNrordcnfmes($para);
            $this->entityManager->persist($configuracao);
            $this->entityManager->flush();

            $this->atualizarPratos($cdservfili, $dtrefecnfmes, $de, $para);
        }

        }catch(\Exception $e) {
            throw $e;
        }
    }
}